## START: Set by rpmautospec
## (rpmautospec version 0.6.1)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

#%%global gittag 1.6.2
%global commit 35878a35f1982b381683cc46e26c4c61011b9d94
%global shortcommit %(c=%{commit}; echo ${c:0:7})
%global date 20240503

Name:           celestia
%if "%{?gittag}"
Version:        1.6.2
%else
# This is a really dirty hack to overcome a wrong update path due to git commit hash
# previously applied without '.git'.
# I don't want to bump Epoch, so I'm going to add a leading '3' before %%{date}
# until version 1.7.0 is finally released.
Version:        1.7.0~3%{date}.git%{shortcommit}
%endif
Release:        %autorelease
Summary:        OpenGL real-time visual space simulation
# Bundled R128 is under Unlicense
License:        GPL-2.0-or-later AND MIT AND Unlicense
URL:            https://celestiaproject.space/
%if "%{?gittag}"
Source0:        https://github.com/CelestiaProject/Celestia/archive/%{gittag}/Celestia-%{version}.tar.gz
%else
Source0:        https://github.com/CelestiaProject/Celestia/archive/%{commit}/Celestia-%{shortcommit}.tar.gz
%endif

# Fix metadata and desktop files
# https://github.com/CelestiaProject/Celestia/pull/2150
Patch:          062333219fa9ea6fa43e52f005cd356edf02dbe7.patch

# Fix for gtk2 build
# https://github.com/CelestiaProject/Celestia/pull/2149
Patch:          ca50d556daff6bad6ef3cf0cb4207ed35f2114ad.patch

# https://fedoraproject.org/wiki/Changes/EncourageI686LeafRemoval
ExcludeArch:    %{ix86}

BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  desktop-file-utils
BuildRequires:  gettext-devel
BuildRequires:  gperf
BuildRequires:  libappstream-glib
BuildRequires:  ImageMagick

BuildRequires:  ffmpeg-free-devel
BuildRequires:  miniaudio-devel
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  pkgconfig(fmt)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(libavif)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
%ifarch x86_64 aarch64
BuildRequires:  pkgconfig(luajit)
%else
BuildRequires:  pkgconfig(lua)
%endif

Provides:       bundled(r128) = 1.6.0


%description
Celestia is a real-time space simulation which lets you experience the
universe in three dimensions. Celestia does not confine you to the
surface of the Earth, it allows you to travel throughout the solar
system, to any of over 100,000 stars, or even beyond the galaxy.

Travel in Celestia is seamless; the exponential zoom feature lets
you explore space across a huge range of scales, from galaxy clusters
down to spacecraft only a few meters across. A 'point-and-goto'
interface makes it simple to navigate through the universe to the
object you want to visit.


%package        common
Summary:        Common files for %{name}
Requires:       celestia-data
Requires:       google-noto-sans-fonts
Requires:       tzdata

Obsoletes:      %{name} < 1.6.3

%description    common
This package provides files common to all GUIs for %{name}.


%package        qt
Summary:        QT interface for %{name}
Requires:       %{name}-common%{?_isa} = %{version}-%{release}

BuildRequires:  qt6-qtbase-devel
BuildRequires:  qt6-qt5compat-devel
BuildRequires:  qt6-qtbase-private-devel
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(wayland-scanner)

%description    qt
This package provides the QT GUI for %{name}.


%package        gtk
Summary:        GTK interface for %{name}
Requires:       %{name}-common%{?_isa} = %{version}-%{release}

Provides:       %{name} = %{version}-%{release}

BuildRequires:  cairo-devel
BuildRequires:  gtk3-devel
BuildRequires:  gtkglext-devel

%description    gtk
This package provides the GTK GUI for %{name}.


%package        doc
Summary:        Documentation files for %{name}
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}

%description    doc
The %{name}-doc package contains documentation for %{name}.


%prep
%if "%{?gittag}"
%autosetup -p1
%else
%autosetup -n Celestia-%{commit} -p1
%endif

# Change default config
sed -i 's|# LeapSecondsFile "|LeapSecondsFile "|g' celestia.cfg
sed -i 's|DejaVuSans.ttf,9"|%{_datadir}/fonts/google-noto/NotoSans-Regular.ttf,9"|g' celestia.cfg
sed -i 's|DejaVuSans-Bold.ttf,15"|%{_datadir}/fonts/google-noto/NotoSans-Bold.ttf,15"|g' celestia.cfg


%build
%cmake -DENABLE_DATA=ON \
       -DENABLE_QT5=OFF \
       -DENABLE_QT6=ON \
       -DENABLE_GTK=ON \
       -DENABLE_FFMPEG=ON \
       -DENABLE_MINIAUDIO=ON \
       -DENABLE_LIBAVIF=ON \
       -DUSE_WAYLAND=ON \
       -DGIT_COMMIT="%{shortcommit}"
#       -DENABLE_GLES=ON \ Disabled due to missing support on QT
#       -DUSE_GTK3=ON \ is broken

%cmake_build

# create standard size icons
convert src/celestia/qt/Celestia.ico hi-apps-celestia.png


%install
%cmake_install

# fix icon name used in GTK app
mv %{buildroot}%{_datadir}/pixmaps/celestia{,-logo}.png
# use standard size and location for desktop icons
for f in hi-apps-celestia-*.png ; do
  d=$(identify -format "%wx%h" $f) ;
  install -D -m0644 $f %{buildroot}%{_datadir}/icons/hicolor/$d/apps/celestia.png ;
done

%find_lang %{name} --all-name

rm %{buildroot}%{_datadir}/celestia/COPYING

# Use system provided fonts
rm -Rf %{buildroot}%{_datadir}/%{name}/fonts


%check
# Menu entry
desktop-file-validate %{buildroot}%{_datadir}/applications/space.celestiaproject.%{name}_{gtk,qt6}.desktop

# Appdata file check
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/space.celestiaproject.%{name}_{gtk,qt6}.metainfo.xml


# No file in the main celestia package
# it's just a metapackage to provide a clean upgrade path from celestia < 1.7
# requiring by default celestia-gtk

%files common -f %{name}.lang
%doc AUTHORS ChangeLog README coding-standards.html
%doc CONTRIBUTING.md devguide.txt
%license COPYING
%{_libdir}/lib%{name}.so.1.7*
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/pixmaps/%{name}-logo.png
%{_datadir}/%{name}
%exclude %{_datadir}/%{name}/help

%files qt
%{_bindir}/%{name}-qt6
%{_mandir}/man1/%{name}-qt6.1*
%{_datadir}/metainfo/space.celestiaproject.%{name}_qt6.metainfo.xml
%{_datadir}/applications/space.celestiaproject.%{name}_qt6.desktop

%files gtk
%{_bindir}/%{name}-gtk
%{_mandir}/man1/%{name}-gtk.1*
%{_datadir}/metainfo/space.celestiaproject.%{name}_gtk.metainfo.xml
%{_datadir}/applications/space.celestiaproject.%{name}_gtk.desktop

%files doc
%{_datadir}/%{name}/help


%changelog
## START: Generated by rpmautospec
* Sat Mar 09 2024 Mattia Verga <mattia.verga@proton.me> - 1.7.0~320240503.git35878a3-1
- Uncommitted changes

* Fri Feb 16 2024 Jan Grulich <jgrulich@redhat.com> - 1.7.0~320231229.git6899839-5
- Rebuild (qt6)

* Wed Jan 31 2024 František Zatloukal <fzatlouk@redhat.com> - 1.7.0~320231229.git6899839-4
- Rebuilt for libavif 1.0.3

* Tue Jan 23 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.7.0~320231229.git6899839-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Fri Jan 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.7.0~320231229.git6899839-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Fri Dec 29 2023 Mattia Verga <mattia.verga@proton.me> - 1.7.0~320231229.git6899839-1
- Update git snapshot

* Wed Nov 29 2023 Jan Grulich <jgrulich@redhat.com> - 1.7.0~320231125.git7ca8fe3-2
- Rebuild (qt6)

* Sat Nov 25 2023 Mattia Verga <mattia.verga@proton.me> - 1.7.0~320231125.git7ca8fe3-1
- Update to latest snapshot

* Fri Oct 13 2023 Jan Grulich <jgrulich@redhat.com> - 1.7.0~320230812.gitcbdeede-4
- Rebuild (qt6)

* Thu Oct 05 2023 Jan Grulich <jgrulich@redhat.com> - 1.7.0~320230812.gitcbdeede-3
- Rebuild (qt6)

* Wed Sep 27 2023 Mattia Verga <mattia.verga@proton.me> - 1.7.0~320230812.gitcbdeede-2
- Explicitly require tzdata

* Sat Aug 12 2023 Mattia Verga <mattia.verga@proton.me> - 1.7.0~320230812.gitcbdeede-1
- Update to latest git commit
- Enable Miniaudio support

* Wed Jul 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.7.0~320230716.git8f43b0b-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Mon Jul 17 2023 Mattia Verga <mattia.verga@proton.me> - 1.7.0~320230716.git8f43b0b-1
- Dirty hack to fix upgrade path.

* Sun Jul 16 2023 Mattia Verga <mattia.verga@proton.me> - 1.7.0~20230716.git8f43b0b-1
- Update to latest snapshot

* Mon Jul 03 2023 Mattia Verga <mattia.verga@proton.me> - 1.7.0~202305157cf93d9-5
- Update URL to new domain name

* Wed Jun 28 2023 Vitaly Zaitsev <vitaly@easycoding.org> - 1.7.0~202305157cf93d9-4
- Rebuilt due to fmt 10 update.

* Mon May 29 2023 Mattia Verga <mattia.verga@proton.me> - 1.7.0~202305157cf93d9-3
- Remove patch merged upstream

* Mon May 29 2023 Mattia Verga <mattia.verga@proton.me> - 1.7.0~202305157cf93d9-2
- Use Fedora default system fonts

* Mon May 15 2023 Mattia Verga <mattia.verga@proton.me> - 1.7.0~202305157cf93d9-1
- Update to latest commit
- Fix missing help file
- Remove upstreamed patch

* Sun Mar 19 2023 Mattia Verga <mattia.verga@proton.me> - 1.7.0~20230305ebfcdb1-6
- Revert previous change

* Sun Mar 19 2023 Mattia Verga <mattia.verga@proton.me> - 1.7.0~20230305ebfcdb1-5
- Fix upgrade path

* Sun Mar 12 2023 Neal Gompa <ngompa@fedoraproject.org> - 1.7.0~20230305ebfcdb1-4
- Rebuild for ffmpeg 6.0

* Mon Mar 06 2023 Mattia Verga <mattia.verga@proton.me> - 1.7.0~20230305ebfcdb1-3
- Remove flatpak conditional for qt5/qt6

* Sun Mar 05 2023 Mattia Verga <mattia.verga@proton.me> - 1.7.0~20230305ebfcdb1-1
- Update to git snapshot of 1.7 preview
- Update license tag to SPDX
- Provide gtk (default) and qt GUIs only
- Stop building on ix86
- Enable ffmpeg and libavif support

* Wed Jan 18 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.2-0.9.beta3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Wed Jul 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.2-0.8.beta3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Wed Jan 19 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.2-0.7.beta3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Wed Jul 21 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.2-0.6.beta3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.2-0.5.beta3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Fri Aug 21 2020 Tom Callaway <spot@fedoraproject.org> - 1.6.2-0.4.beta3
- Shrox's models are now CC-BY, switch to upstream tarball!

* Thu Aug 20 2020 Tom Callaway <spot@fedoraproject.org> - 1.6.2-0.3.beta3
- Successfully relicensed Scott Hudson's asteroid models to a FOSS & GPLv2+ compatible license
- generated new clean tarball

* Mon Jul 27 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.2-0.2.beta3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Mon Jul 13 2020 Tom Callaway <spot@fedoraproject.org> - 1.6.2-0.1.beta3
- update to 1.6.2-beta3
- fixes for lua 5.4

* Tue Jan 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.1-33
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Fri Aug 23 2019 Mamoru TASAKA <mtasaka@fedoraproject.org> - 1.6.1-32
- Fix FTBFS, fix linkage order

* Wed Jul 24 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.1-31
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.1-30
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Tue Jul 31 2018 Florian Weimer <fweimer@redhat.com> - 1.6.1-29
- Rebuild with fixed binutils

* Thu Jul 12 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.1-28
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.1-27
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.1-26
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.1-25
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon May 15 2017 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.1-24
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.1-23
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.1-22
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.1-21
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 1.6.1-20
- Rebuilt for GCC 5 C++11 ABI change

* Thu Mar 26 2015 Richard Hughes <rhughes@redhat.com> - 1.6.1-19
- Add an AppData file for the software center

* Sun Nov 16 2014 Matias Kreder <mkreder@gmail.com> - 1.6.1-18
- Repackaged source with .tar.xz

* Fri Aug 15 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.1-17
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Thu Jul 03 2014 Richard Hughes <richard@hughsie.com> - 1.6.1-16
- Fix startup, thanks to a patch from Chris Rankin
- Resolves: #1045632

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.1-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Aug 22 2013 Ralf Corsépius <corsepiu@fedoraproject.org> - 1.6.1-14
- FTBS, RHBZ#992048:
  - celestia-1.6.1-lua-5.2.patch: Add autoconf-2.67 generated snippets.
  Avoid running autotools (package config is incompatible to modern autotools).
  - Add celestia-1.6.1-gcc4.8.patch: Tweaks for building with gcc-4.8.x.
- Address docdir changes (RHBZ#993693).
- Fix permissons on source files.

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.1-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue May 14 2013 Tom Callaway <spot@fedoraproject.org> - 1.6.1-12
- rebuild for lua 5.2

* Thu Feb 14 2013 Rahul Sundaram <sundaram@fedoraproject.org> - 1.6.1-11
- remove vendor tag from desktop file. https://fedorahosted.org/fpc/ticket/247
- clean up spec to follow current guidelines
- fix desktop file to follow specification

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.1-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Jan 18 2013 Adam Tkac <atkac redhat com> - 1.6.1-9
- rebuild due to "jpeg8-ABI" feature drop

* Mon Jan 14 2013 Tom Callaway <spot@fedoraproject.org> - 1.6.1-8
- remove non-free (or unlicensed) files (bz 888210)

* Fri Dec 21 2012 Adam Tkac <atkac redhat com> - 1.6.1-7
- rebuild against new libjpeg

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Mar 22 2012 Tom Callaway <spot@fedoraproject.org> - 1.6.1-5
- fix compile issues (gcc 4.7, zlib)

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.1-4
- Rebuilt for c++ ABI breakage

* Thu Jan 12 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Dec 06 2011 Adam Jackson <ajax@redhat.com> - 1.6.1-2
- Rebuild for new libpng

* Mon Nov 14 2011 Peter Robinson <pbrobinson@fedoraproject.org> - 1.6.1-1
- Update to 1.6.1

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Dec 15 2010 Hans de Goede <hdegoede@redhat.com> - 1.6.0-2
- Fix the license button in the about dialog not working

* Wed Dec  8 2010 Hans de Goede <hdegoede@redhat.com> - 1.6.0-1
- New upstream release 1.6.0 (#655565)
- Fix building with gcc-4.5 (#631077)

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sun Apr 12 2009 Lubomir Rintel <lkundrak@v3.sk> - 1.5.1-1
- New upstream release

* Sun Mar  1 2009 Lubomir Rintel <lkundrak@v3.sk> - 1.5.0-3
- Fix build with GCC 4.4

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Mar  1 2008 Marek Mahut <mmahut@fedoraproject.org> - 1.5.0-1
- Upstream release 1.5.0 and dropping unnecessary patches
- celestia-1.5.0-gcc43.patch (#434441)
- Moving to education category (#220793)

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.4.1-8
- Autorebuild for GCC 4.3

* Wed Nov 22 2006 Steven Pritchard <steve@kspei.com> 1.4.1-7
- Really fix the cmod models problem (#203525).  (Thanks to Hans de Goede.)
- Hopefully really handle the gconf schema properly.

* Mon Aug 28 2006 Steven Pritchard <steve@kspei.com> 1.4.1-6
- Add --disable-schemas-install to configure.

* Tue Aug 22 2006 Steven Pritchard <steve@kspei.com> 1.4.1-5
- Turn on -fno-strict-aliasing to work around bug #203525.

* Mon Jul 31 2006 Steven Pritchard <steve@kspei.com> 1.4.1-4
- We modified configure.in, so now we need automake17 and gettext-devel.

* Mon Jul 31 2006 Nick Urbanik <nicku@nicku.org> 1.4.1-3
- Test errorMessage to see if it is null before copying it!
  This change suggested by Hank Ramsey and added to
  celestia-1.4.1-lua51-resume.patch
- Added developers documentation
- Incorporate patch suggested by Hank Ramsey to eliminate segfault
  when loading .celx files: celestia-1.4.1-lua51-resume.patch
- Update to add lua
- Incorporate
  http://www.archlinux.org/pipermail/tur-users/attachments/20060603/7dea8cd1/celestia-lua51.bin

* Fri May 19 2006 Steven Pritchard <steve@kspei.com> 1.4.1-2
- Include accidentally dropped 3ds models.

* Tue Mar 28 2006 Steven Pritchard <steve@kspei.com> 1.4.1-1
- Update to 1.4.1
- Use "pkg-config --libs gtkglext-x11-1.0 libgnomeui-2.0" instead of
  "pkg-config --libs gtk+-2.0"

* Fri Feb 10 2006 Steven Pritchard <steve@kspei.com> 1.4.0.20060210cvs-1
- Update to today's CVS snapshot

* Fri Feb 10 2006 Steven Pritchard <steve@kspei.com> 1.4.0-3
- Add celestia-1.4.0-compile.patch to fix a bug when compiling with g++ 4.1

* Thu Jan 05 2006 Steven Pritchard <steve@kspei.com> 1.4.0-2
- Add BR: libGLU-devel, libXt-devel, libXmu-devel
- Add -lpangox-1.0 to GTK_LIBS

* Mon Dec 26 2005 Steven Pritchard <steve@kspei.com> 1.4.0-1
- Update to 1.4.0
- Remove celestia-1.3.2-compile.patch (seems to be applied upstream)
- Use find_lang magic
- Remove duplicate desktop file
- Fix Help -> Controls

* Sat Dec 03 2005 Steven Pritchard <steve@kspei.com> 1.3.2-5
- BR libGL-devel instead of xorg-x11-Mesa-libGL

* Sun May 22 2005 Jeremy Katz <katzj@redhat.com> - 1.3.2-4
- rebuild on all arches

* Fri Apr  7 2005 Michael Schwendt <mschwendt[AT]users.sf.net>
- rebuilt

* Wed Nov 10 2004 Matthias Saou <http://freshrpms.net/> 1.3.2-2
- Bump release to provide Extras upgrade path.

* Wed Nov 10 2004 Marius L. Jøhndal <mariuslj at ifi.uio.no> - 0:1.3.2-0.fdr.2
- Fixed FC3 compilation.

* Sat Aug 28 2004 Marius L. Jøhndal <mariuslj at ifi.uio.no> - 0:1.3.2-0.fdr.1
- Updated to 1.3.2.
- Switched to using GNOME frontend.
- Updated desktop file.
- Minor editing of description text.
- Converted spec file to UTF-8.

* Thu Nov 27 2003 Marius L. Jøhndal <mariuslj at ifi.uio.no> - 0:1.3.0-0.fdr.4
- Added build req gtkglarea (bug 740).

* Thu Nov 27 2003 Marius L. Jøhndal <mariuslj at ifi.uio.no> - 0:1.3.0-0.fdr.3
- Added Encoding=UTF-8 to desktop file (bug 740).
- Added work-around for linking problems on FC1 (bug 740).
- Updated {minor,numbered}moons.asc (bug 740).

* Wed Oct  8 2003 Marius L. Jøhndal <mariuslj at ifi.uio.no> - 0:1.3.0-0.fdr.2
- Replaced source tarball with proper release tarball.
- Added BuildRequires gnome-libs-devel for gnomeConf.sh.
- Build with freeglut instead of glut.

* Wed Sep 17 2003 Marius L. Jøhndal <mariuslj at ifi.uio.no> - 0:1.3.0-0.fdr.1
- Initial Fedora RPM release.

* Thu Apr 17 2003 Matthias Saou <matthias.saou@est.une.marmotte.net>
- Update to 1.3.0.
- Added numberedmoons.ssc addon.

* Mon Mar 31 2003 Matthias Saou <matthias.saou@est.une.marmotte.net>
- Rebuilt for Red Hat Linux 9.

* Tue Jan 14 2003 Matthias Saou <matthias.saou@est.une.marmotte.net>
- Update to 1.2.5.
- Included "Minor Moons of the Giant Planets" extra file.
- New icon from the KDE part of the source.

* Sat Sep 28 2002 Matthias Saou <matthias.saou@est.une.marmotte.net>
- Rebuilt for Red Hat Linux 8.0.
- New style menu entry.

* Wed Jul  3 2002 Matthias Saou <matthias.saou@est.une.marmotte.net>
- Rebuilt to remove the NVidia dependency (oops!).

* Wed May 15 2002 Matthias Saou <matthias.saou@est.une.marmotte.net>
- Sorry, I'm a maniac ;-)

* Tue May 14 2002 Julien MOUTTE <julien@moutte.net>
- Initial RPM release.

## END: Generated by rpmautospec
